<?php
/**
 * @package Catch Themes
 * @subpackage Catch Evolution
 * @since Catch Evolution 2.6
 */

//@remove Remove block when WP v4.8	 is released
if( ! function_exists( 'catchevolution_is_favicon_active' ) ) :
	/**
	* Return true if no core site icon is present
	*
	* @since Catch Evolution 2.6
	*/
	function catchevolution_is_site_icon_active( $control ) {
		//Check if has_site_icon function exists. If it does not, WP version is less than 4.3
		if ( function_exists( 'has_site_icon' ) ) {
			//Return true if core site icon is not present, else return false
			return !has_site_icon();
		}
		else {
			return true;
		}
	}
endif;


if( ! function_exists( 'catchevolution_is_feed_url_present' ) ) :
	/**
	* Return true if feed url is present
	*
	* @since Catch Evolution 2.6
	*/
	function catchevolution_is_feed_url_present( $control ) {
		global $catchevolution_options_settings;

    	$options = $catchevolution_options_settings;

		return ( isset( $options['feed_url'] ) && '' != $options['feed_url'] );
	}
endif;


if( ! function_exists( 'catchevolution_is_header_code_present' ) ) :
	/**
	* Return true if header code is present
	*
	* @since Catch Evolution 2.6
	*/
	function catchevolution_is_header_code_present( $control ) {
		global $catchevolution_options_settings;

    	$options = $catchevolution_options_settings;

		return ( isset( $options['analytic_header'] ) && '' != $options['analytic_header'] );
	}
endif;


if( ! function_exists( 'catchevolution_is_footer_code_present' ) ) :
	/**
	* Return true if footer code is present
	*
	* @since Catch Evolution 2.6
	*/
	function catchevolution_is_footer_code_present( $control ) {
		global $catchevolution_options_settings;

    	$options = $catchevolution_options_settings;

		return ( isset( $options['analytic_footer'] ) && '' != $options['analytic_footer'] );
	}
endif;

if( ! function_exists( 'catchevolution_is_slider_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since Catch Evolution Pro 3.2
	*/
	function catchevolution_is_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchevolution_options[enable_slider]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) );
	}
endif;


if( ! function_exists( 'catchevolution_is_demo_slider_inactive' ) ) :
	/**
	* Return true if demo slider is inactive
	*
	* @since Catch Evolution Pro 3.2
	*/
	function catchevolution_is_demo_slider_inactive( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchevolution_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catchevolution_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) ) && !( 'demo-slider' == $type ) );
	}
endif;


if( ! function_exists( 'catchevolution_is_post_slider_active' ) ) :
	/**
	* Return true if post slider is active
	*
	* @since Catch Evolution Pro 3.2
	*/
	function catchevolution_is_post_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchevolution_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catchevolution_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) ) && 'post-slider' == $type );
	}
endif;

if( ! function_exists( 'catchevolution_is_page_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Catch Evolution Pro 3.2
	*/
	function catchevolution_is_page_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchevolution_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catchevolution_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) ) && 'page-slider' == $type );
	}
endif;

if( ! function_exists( 'catchevolution_is_image_slider_active' ) ) :
	/**
	* Return true if image slider is active
	*
	* @since Catch Evolution Pro 3.2
	*/
	function catchevolution_is_image_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchevolution_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catchevolution_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) ) && 'image-slider' == $type );
	}
endif;


if( ! function_exists( 'catchevolution_is_category_slider_active' ) ) :
	/**
	* Return true if category slider is active
	*
	* @since Catch Evolution Pro 3.2
	*/
	function catchevolution_is_category_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchevolution_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catchevolution_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) ) && 'category-slider' == $type );
	}
endif;

if( ! function_exists( 'catchevolution_is_header_featured_image_enabled' ) ) :
	/**
	* Return true if header featured image enabled
	*
	* @since Catch Evolution Pro 3.2
	*/
	function catchevolution_is_header_featured_image_enabled( $control ) {

		$enable = $control->manager->get_setting( 'catchevolution_options[enable_featured_header_image]' )->value();

		return ( 'disable' != $enable );

	}
endif;