<?php
/**
 * Catch Evolution Customizer/Theme Options
 *
 * @package Catch Themes
 * @subpackage Catch Evolution
 * @since Catch Evolution 2.6
 */

/**
 * Implements Catch Evolution theme options into Theme Customizer.
 *
 * @param $wp_customize Theme Customizer object
 * @return void
 *
 * @since Catch Evolution 2.6
 */
function catchevolution_customize_register( $wp_customize ) {
	global $catchevolution_options_settings, $catchevolution_options_defaults;

    $options = $catchevolution_options_settings;

	$defaults = $catchevolution_options_defaults;

	//Custom Controls
	require get_template_directory() . '/inc/panel/customizer/customizer-custom-controls.php';

	$theme_slug = 'catchevolution_';

	$settings_page_tabs = array(
		'theme_options' => array(
			'id' 			=> 'theme_options',
			'title' 		=> __( 'Theme Options', 'catch-evolution-pro' ),
			'description' 	=> __( 'Basic theme Options', 'catch-evolution-pro' ),
			'sections' 		=> array(
				'responsive_design' => array(
					'id' 				=> 'responsive_design',
					'title' 			=> __( 'Responsive Design', 'catch-evolution-pro' ),
					'description' 		=> '',
				),
				'favicon' => array(
					'id' 				=> 'favicon',
					'title' 			=> __( 'Favicon', 'catch-evolution-pro' ),
					'description' 		=> '',
					'active_callback'	=> 'catchevolution_is_site_icon_active',
				),
				'web_clip_icon_options' => array(
					'id' 				=> 'web_clip_icon_options',
					'title' 			=> __( 'Web Clip Icon Options', 'catch-evolution-pro' ),
					'description' 		=> __( 'Web Clip Icon for Apple devices. Recommended Size - Width 144px and Height 144px height, which will support High Resolution Devices like iPad Retina', 'catch-evolution-pro' ),
					'active_callback'	=> 'catchevolution_is_site_icon_active',
				),
				'header_options' => array(
					'id' 			=> 'header_options',
					'title' 		=> __( 'Header Options', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
				'search_text_settings' => array(
					'id' 			=> 'search_text_settings',
					'title' 		=> __( 'Search Text Settings', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
				'typography' => array(
					'id' 			=> 'typography',
					'title' 		=> __( 'Font Family Options', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
				'typography_size' => array(
					'id' 			=> 'typography_size',
					'title' 		=> __( 'Font Size Options', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
				'layout_options' => array(
					'id' 			=> 'layout_options',
					'title' 		=> __( 'Layout Options', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
				'homepage_settings' => array(
					'id' 			=> 'homepage_settings',
					'title' 		=> __( 'Homepage / Frontpage Category Setting', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
				'excerpt_more_tag_settings' => array(
					'id' 			=> 'excerpt_more_tag_settings',
					'title' 		=> __( 'Excerpt / More Tag Settings', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
				'feed_url' => array(
					'id' 			=> 'feed_url',
					'title' 		=> __( 'Feed Redirect', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
				'comment_settings' => array(
					'id' 			=> 'comment_settings',
					'title' 		=> __( 'Comment Options', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
				'footer_options' => array(
					'id' 			=> 'footer_options',
					'title' 		=> __( 'Footer Editor Option', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
				'custom_css' => array(
					'id' 			=> 'custom_css',
					'title' 		=> __( 'Custom CSS', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
				'update_notifier' => array(
					'id' 			=> 'update_notifier',
					'title' 		=> __( 'Update Notifier', 'catch-evolution-pro' ),
					'description' 	=> '',
				),

			),
		),
		'featured_slider' => array(
			'id' 			=> 'featured_slider',
			'title' 		=> __( 'Featured Slider', 'catch-evolution-pro' ),
			'description' 	=> __( 'Featured Slider', 'catch-evolution-pro' ),
			'sections' 		=> array(
				'slider_options' => array(
					'id' 			=> 'slider_options',
					'title' 		=> __( 'Slider Options', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
			)
		),

		'social_links' => array(
			'id' 			=> 'social_links',
			'title' 		=> __( 'Social Links', 'catch-evolution-pro' ),
			'description' 	=> __( 'Add your social links here', 'catch-evolution-pro' ),
			'sections' 		=> array(
				'social_links' => array(
					'id' 			=> 'social_links',
					'title' 		=> __( 'Social Links', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
			),
		),
		'webmaster_tool' => array(
			'id' 			=> 'webmaster_tool',
			'title' 		=> __( 'Webmaster Tools', 'catch-evolution-pro' ),
			'description' 	=> '',
			'sections' 		=> array(
				'site_verification' => array(
					'id' 			=> 'site_verification',
					'title' 		=> __( 'Site Verification', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
				'header_footer_codes' => array(
					'id' 			=> 'header_footer_codes',
					'title' 		=> __( 'Header and Footer Codes', 'catch-evolution-pro' ),
					'description' 	=> '',
				),
			),
		),
	);

	$wp_customize->get_control('header_textcolor')->priority = '180';
	$wp_customize->get_control('header_textcolor')->label 	 = __( 'Site Title Color', 'catch-evolution-pro' );
	$wp_customize->get_control('background_color')->priority = '20';
	$wp_customize->get_control('background_color')->label 	 = __( 'Main Background Color', 'catch-evolution-pro' );

	//Add Panels and sections
	foreach ( $settings_page_tabs as $panel ) {
		$wp_customize->add_panel(
			$theme_slug . $panel['id'],
			array(
				'priority' 		=> 200,
				'capability' 	=> 'edit_theme_options',
				'title' 		=> $panel['title'],
				'description' 	=> $panel['description'],
			)
		);

		// Loop through tabs for sections
		foreach ( $panel['sections'] as $section ) {
			$params = array(
								'title'			=> $section['title'],
								'description'	=> $section['description'],
								'panel'			=> $theme_slug . $panel['id']
							);

			if ( isset( $section['active_callback'] ) ) {
				$params['active_callback'] = $section['active_callback'];
			}

			$wp_customize->add_section(
				// $id
				$theme_slug . $section['id'],
				// parameters
				$params

			);
		}
	}

	//Add Menu Options Section Without a panel
	$wp_customize->add_section(
		'catchevolution_menu_options',
		array(
			'description'	=> __( 'Extra Menu Options specific to this theme', 'catch-evolution-pro' ),
			'priority' 		=> 105,
			'title'    		=> __( 'Menu Options', 'catch-evolution-pro' ),
			)
		);

	$settings_parameters = array(
		//Disable Header Menu
		'disable_header_menu' => array(
			'id' 				=> 'disable_header_menu',
			'title' 			=> __( 'Check to Disable Primary & Secondary Menu', 'catch-evolution-pro' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'catchevolution_sanitize_checkbox',
			'panel' 			=> 'theme_options',
			'section' 			=> 'menu_options',
			'default' 			=> $defaults['disable_header_menu'],
		),
		'top_menu_logo' => array(
			'id' 				=> 'top_menu_logo',
			'title' 			=> __( 'Logo in Fixed Header Top Menu', 'catch-evolution-pro' ),
			'description'		=> __( 'Note: This image will be displayed only after you assign Menu in Fixed Header Top Menu', 'catch-evolution-pro' ),
			'field_type' 		=> 'image',
			'sanitize' 			=> 'catchevolution_sanitize_image',
			'panel' 			=> 'theme_options',
			'section' 			=> 'menu_options',
			'default' 			=> $defaults['top_menu_logo'],
		),

		//Responsive Design
		'disable_responsive' => array(
			'id' 				=> 'disable_responsive',
			'title' 			=> __( 'Check to Disable Responsive Design', 'catch-evolution-pro' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'catchevolution_sanitize_checkbox',
			'panel' 			=> 'theme_options',
			'section' 			=> 'responsive_design',
			'default' 			=> $defaults['disable_responsive'],
		),
		'enable_menus' => array(
			'id' 				=> 'enable_menus',
			'title' 			=> __( 'Check to Enable Secondary & Footer Menu in Mobile Devices', 'catch-evolution-pro' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'catchevolution_sanitize_checkbox',
			'panel' 			=> 'theme_options',
			'section' 			=> 'responsive_design',
			'default' 			=> $defaults['enable_menus'],
		),

		//Header Options
		'disable_header' => array(
			'id' 			=> 'disable_header',
			'title' 		=> __( 'Check to Disable Header', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchevolution_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['disable_header']
		),
		'disable_header_content' => array(
			'id' 			=> 'disable_header_content',
			'title' 		=> __( 'Check to Disable Header Content', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchevolution_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['disable_header_content']
		),
		'remove_site_title' => array(
			'id' 			=> 'remove_site_title',
			'title' 		=> __( 'Check to Disable Site Title', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchevolution_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['remove_site_title']
		),
		'remove_site_title' => array(
			'id' 			=> 'remove_site_title',
			'title' 		=> __( 'Check to Disable Site Title', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchevolution_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['remove_site_title']
		),
		'site_title_above' => array(
			'id' 			=> 'site_title_above',
			'title' 		=> __( 'Check to Move Site Title and Tagline before the logo', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchevolution_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['site_title_above']
		),
		'seperate_logo' => array(
			'id' 			=> 'seperate_logo',
			'title' 		=> __( 'Check to Separate Logo and Site Details', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchevolution_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['seperate_logo']
		),
		'header_top_size' => array(
			'id' 			=> 'header_top_size',
			'title' 		=> __( 'Header Top Margin', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['header_top_size']
		),
		'header_bottom_size' => array(
			'id' 			=> 'header_bottom_size',
			'title' 		=> __( 'Header Bottom Margin', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['header_bottom_size']
		),
		'reset_header_space' => array(
			'id' 			=> 'reset_header_space',
			'title' 		=> __( 'Check to Reset Header Margin', 'catch-evolution-pro' ),
			'description'	=> __( 'Please refresh the customizer after saving if reset option is used', 'catch-evolution-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchevolution_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['reset_header_space'],
			'priority'		=> '999'
		),

		//Header Featured Image
		'enable_featured_header_image' => array(
			'id' 			=> 'enable_featured_header_image',
			'title' 		=> __( 'Enable Header Featured Image on', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchevolution_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_image',
			'default' 		=> $defaults['enable_featured_header_image'],
			'choices'		=> catchevolution_enable_header_featured_image(),
		),
		'page_featured_image' => array(
			'id' 				=> 'page_featured_image',
			'title' 			=> __( 'Page/Post Featured Image Size', 'catch-evolution-pro' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'catchevolution_sanitize_select',
			'panel' 			=> 'theme_options',
			'section' 			=> 'header_image',
			'default' 			=> $defaults['page_featured_image'],
			'choices'			=> catchevolution_page_post_featured_image_size(),
			'active_callback'	=> 'catchevolution_is_header_featured_image_enabled'
		),
		'featured_header_image_position' => array(
			'id' 				=> 'featured_header_image_position',
			'title' 			=> __( 'Featured Header Image Position', 'catch-evolution-pro' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'catchevolution_sanitize_select',
			'panel' 			=> 'theme_options',
			'section' 			=> 'header_image',
			'default' 			=> $defaults['featured_header_image_position'],
			'choices'			=> catchevolution_featured_image_position(),
			'active_callback'	=> 'catchevolution_is_header_featured_image_enabled'
		),
		'featured_header_image_alt' => array(
			'id' 				=> 'featured_header_image_alt',
			'title' 			=> __( 'Featured Header Image Alt/Title Tag', 'catch-evolution-pro' ),
			'description'		=> '',
			'field_type' 		=> 'text',
			'sanitize' 			=> 'sanitize_text_field',
			'panel' 			=> 'theme_options',
			'section' 			=> 'header_image',
			'default' 			=> $defaults['featured_header_image_alt'],
			'active_callback'	=> 'catchevolution_is_header_featured_image_enabled'
		),
		'featured_header_image_url' => array(
			'id' 				=> 'featured_header_image_url',
			'title' 			=> __( 'Feature Header Image Link URL', 'catch-evolution-pro' ),
			'description'		=> '',
			'field_type' 		=> 'url',
			'sanitize' 			=> 'esc_url_raw',
			'panel' 			=> 'theme_options',
			'section' 			=> 'header_image',
			'default' 			=> $defaults['featured_header_image_url'],
			'active_callback'	=> 'catchevolution_is_header_featured_image_enabled'
		),
		'featured_header_image_base' => array(
			'id' 				=> 'featured_header_image_base',
			'title' 			=> __( 'Check to Open Link in New Window', 'catch-evolution-pro' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'catchevolution_sanitize_checkbox',
			'panel' 			=> 'theme_options',
			'section' 			=> 'header_image',
			'default' 			=> $defaults['featured_header_image_base'],
			'active_callback'	=> 'catchevolution_is_header_featured_image_enabled'
		),
		'reset_header_image' => array(
			'id' 				=> 'reset_header_image',
			'title' 			=> __( 'Check to Reset Header Featured Image Option', 'catch-evolution-pro' ),
			'description'		=> __( 'Please refresh the customizer after saving if reset option is used', 'catch-evolution-pro' ),
			'transport'			=> 'postMessage',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'catchevolution_sanitize_checkbox',
			'panel' 			=> 'theme_options',
			'section' 			=> 'header_image',
			'default' 			=> $defaults['reset_header_image'],
			'active_callback'	=> 'catchevolution_is_header_featured_image_enabled'
		),

		//Search Settings
		'search_display_text' => array(
			'id' 			=> 'search_display_text',
			'title' 		=> __( 'Default Display Text in Search', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'text',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'search_text_settings',
			'default' 		=> $defaults['search_display_text']
		),

		//Color Options
		'color_scheme' => array(
			'id' 			=> 'color_scheme',
			'title' 		=> __( 'Default Color Scheme', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'radio',
			'sanitize' 		=> 'catchevolution_sanitize_select',
			'section' 		=> 'colors',
			'default' 		=> $defaults['color_scheme'],
			'choices'		=> catchevolution_color_schemes(),
			'priority'		=> '10',
		),
		'header_background' => array(
			'id' 			=> 'header_background',
			'title' 		=> __( 'Header Background', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['header_background'],
			'priority'		=> '50',
		),
		'header_image_background' => array(
			'id' 			=> 'header_image_background',
			'title' 		=> __( 'Header Image Background', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['header_image_background'],
			'priority'		=> '60',
		),
		'slider_background' => array(
			'id' 			=> 'slider_background',
			'title' 		=> __( 'Slider Background Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['slider_background'],
			'priority'		=> '70',
		),
		'content_background' => array(
			'id' 			=> 'content_background',
			'title' 		=> __( 'Content Background Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['content_background'],
			'priority'		=> '80',
		),
		'article_background' => array(
			'id' 			=> 'article_background',
			'title' 		=> __( 'Article Background Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['article_background'],
			'priority'		=> '90',
		),
		'footer_background' => array(
			'id' 			=> 'footer_background',
			'title' 		=> __( 'Footer Background Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['footer_background'],
			'priority'		=> '100',
		),
		'footer_sidebar_background' => array(
			'id' 			=> 'footer_sidebar_background',
			'title' 		=> __( 'Footer Sidebar Background Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['footer_sidebar_background'],
			'priority'		=> '110',
		),
		'widget_background' => array(
			'id' 			=> 'widget_background',
			'title' 		=> __( 'Widget Background Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['widget_background'],
			'priority'		=> '120',
		),
		'widget_footer_background' => array(
			'id' 			=> 'widget_footer_background',
			'title' 		=> __( 'Footer Widget Background Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['widget_footer_background'],
			'priority'		=> '130',
		),
		'menu_background' => array(
			'id' 			=> 'menu_background',
			'title' 		=> __( 'Menu Background Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['menu_background'],
			'priority'		=> '140',
		),
		'hover_background_color' => array(
			'id' 			=> 'hover_background_color',
			'title' 		=> __( 'Menu Hover Background', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['hover_background_color'],
			'priority'		=> '150',
		),
		'active_background_color' => array(
			'id' 			=> 'active_background_color',
			'title' 		=> __( 'Menu Active Background Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['active_background_color'],
			'priority'		=> '160',
		),
		'sub_menu_bg_color' => array(
			'id' 			=> 'sub_menu_bg_color',
			'title' 		=> __( 'Sub-Menu Background Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['sub_menu_bg_color'],
			'priority'		=> '170',
		),
		'title_hover_color' => array(
			'id' 			=> 'title_hover_color',
			'title' 		=> __( 'Sub-Menu Background Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['title_hover_color'],
			'priority'		=> '190',
		),
		'tagline_color' => array(
			'id' 			=> 'tagline_color',
			'title' 		=> __( 'Site Tagline Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['tagline_color'],
			'priority'		=> '200',
		),
		'heading_color' => array(
			'id' 			=> 'heading_color',
			'title' 		=> __( 'Title Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['heading_color'],
			'priority'		=> '210',
		),
		'heading_hover_color' => array(
			'id' 			=> 'heading_hover_color',
			'title' 		=> __( 'Title Hover Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['heading_hover_color'],
			'priority'		=> '220',
		),
		'slider_text' => array(
			'id' 			=> 'slider_text',
			'title' 		=> __( 'Slider Text Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['slider_text'],
			'priority'		=> '230',
		),
		'meta_color' => array(
			'id' 			=> 'meta_color',
			'title' 		=> __( 'Meta Description Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['meta_color'],
			'priority'		=> '240',
		),
		'text_color' => array(
			'id' 			=> 'text_color',
			'title' 		=> __( 'Text Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['text_color'],
			'priority'		=> '250',
		),
		'link_color' => array(
			'id' 			=> 'link_color',
			'title' 		=> __( 'Link Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['link_color'],
			'priority'		=> '260',
		),
		'widget_heading_color' => array(
			'id' 			=> 'widget_heading_color',
			'title' 		=> __( 'Sidebar Widget Title Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['widget_heading_color'],
			'priority'		=> '270',
		),
		'widget_text_color' => array(
			'id' 			=> 'widget_text_color',
			'title' 		=> __( 'Sidebar Widget Text Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['widget_text_color'],
			'priority'		=> '280',
		),
		'widget_link_color' => array(
			'id' 			=> 'widget_link_color',
			'title' 		=> __( 'Sidebar Widget Link Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['widget_link_color'],
			'priority'		=> '290',
		),
		'menu_color' => array(
			'id' 			=> 'menu_color',
			'title' 		=> __( 'Menu Text Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['menu_color'],
			'priority'		=> '300',
		),
		'hover_text_color' => array(
			'id' 			=> 'hover_text_color',
			'title' 		=> __( 'Menu Hover Text Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['hover_text_color'],
			'priority'		=> '310',
		),
		'active_text_color' => array(
			'id' 			=> 'active_text_color',
			'title' 		=> __( 'Menu Active Text Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['active_text_color'],
			'priority'		=> '320',
		),
		'sub_menu_text_color' => array(
			'id' 			=> 'sub_menu_text_color',
			'title' 		=> __( 'Sub-Menu Text Color', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['sub_menu_text_color'],
			'priority'		=> '330',
		),
		'reset_color' => array(
			'id' 			=> 'reset_color',
			'title' 		=> __( 'Check to Reset Colors', 'catch-evolution-pro' ),
			'description'	=> __( 'Please refresh the customizer after saving if reset option is used', 'catch-evolution-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchevolution_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'colors',
			'default' 		=> $defaults['reset_color'],
			'priority'		=> '340',
		),

		//Typography
		'body_font' => array(
			'id' 			=> 'body_font',
			'title' 		=> __( 'Default Font Family', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchevolution_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography',
			'default' 		=> $defaults['body_font'],
			'choices'		=> catchevolution_available_fonts(),
		),
		'title_font' => array(
			'id' 			=> 'title_font',
			'title' 		=> __( 'Site Title & Description Font Family', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchevolution_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography',
			'default' 		=> $defaults['title_font'],
			'choices'		=> catchevolution_available_fonts(),
		),
		'headings_font' => array(
			'id' 			=> 'headings_font',
			'title' 		=> __( 'Headings Font Family', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchevolution_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography',
			'default' 		=> $defaults['headings_font'],
			'choices'		=> catchevolution_available_fonts(),
		),
		'content_font' => array(
			'id' 			=> 'content_font',
			'title' 		=> __( 'Content Font Family', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchevolution_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography',
			'default' 		=> $defaults['content_font'],
			'choices'		=> catchevolution_available_fonts(),
		),
		'reset_typography' => array(
			'id' 			=> 'reset_typography',
			'title' 		=> __( 'Check to Reset Fonts', 'catch-evolution-pro' ),
			'description'	=> __( 'Please refresh the customizer after saving if reset option is used', 'catch-evolution-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchevolution_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography',
			'default' 		=> $defaults['reset_typography']
		),

		//Typography Size
		'body_font_size' => array(
			'id' 			=> 'body_font_size',
			'title' 		=> __( 'Default Font Size', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['body_font_size']
		),
		'body_line_height' => array(
			'id' 			=> 'body_line_height',
			'title' 		=> __( 'Default Line Height', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['body_line_height']
		),
		'site_title_font_size' => array(
			'id' 			=> 'site_title_font_size',
			'title' 		=> __( 'Site Title Font Size', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['site_title_font_size']
		),
		'site_title_line_height' => array(
			'id' 			=> 'site_title_line_height',
			'title' 		=> __( 'Site Title Line Height', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['site_title_line_height']
		),
		'site_description_font_size' => array(
			'id' 			=> 'site_description_font_size',
			'title' 		=> __( 'Site Description Font Size', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['site_description_font_size']
		),
		'site_description_line_height' => array(
			'id' 			=> 'site_description_line_height',
			'title' 		=> __( 'Site Description Line Height', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['site_description_line_height']
		),
		'h1_font_size' => array(
			'id' 			=> 'h1_font_size',
			'title' 		=> __( 'H1 Font Size', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['h1_font_size']
		),
		'h2_font_size' => array(
			'id' 			=> 'h2_font_size',
			'title' 		=> __( 'H2 Font Size', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['h2_font_size']
		),
		'h3_font_size' => array(
			'id' 			=> 'h3_font_size',
			'title' 		=> __( 'H3 Font Size', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['h3_font_size']
		),
		'h4_font_size' => array(
			'id' 			=> 'h4_font_size',
			'title' 		=> __( 'H4 Font Size', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['h4_font_size']
		),
		'headings_line_height' => array(
			'id' 			=> 'headings_line_height',
			'title' 		=> __( 'Headings Line Height', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['headings_line_height']
		),
		'content_font_size' => array(
			'id' 			=> 'content_font_size',
			'title' 		=> __( 'Content Font Size', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['content_font_size']
		),
		'content_line_height' => array(
			'id' 			=> 'content_line_height',
			'title' 		=> __( 'Content Line Height', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['content_line_height']
		),
		'reset_font_size' => array(
			'id' 			=> 'reset_font_size',
			'title' 		=> __( 'Check to Reset Font Size', 'catch-evolution-pro' ),
			'description'	=> __( 'Please refresh the customizer after saving if reset option is used', 'catch-evolution-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchevolution_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['reset_font_size'],
			'priority'		=> '999',
		),

		//Layout Options
		'sidebar_layout' => array(
			'id' 			=> 'sidebar_layout',
			'title' 		=> __( 'Default Layout', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchevolution_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'layout_options',
			'default' 		=> $defaults['sidebar_layout'],
			'choices'		=> catchevolution_sidebar_layout_options(),
		),
		'woocommerce_layout' => array(
			'id' 			=> 'woocommerce_layout',
			'title' 		=> __( 'WooCommerce Layout', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchevolution_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'layout_options',
			'default' 		=> $defaults['woocommerce_layout'],
			'choices'		=> catchevolution_sidebar_layout_options(),
		),
		'content_layout' => array(
			'id' 			=> 'content_layout',
			'title' 		=> __( 'Content Layout', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchevolution_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'layout_options',
			'default' 		=> $defaults['content_layout'],
			'choices'		=> catchevolution_content_layout_options(),
		),
		'reset_sidebar_layout' => array(
			'id' 			=> 'reset_sidebar_layout',
			'title' 		=> __( 'Check to Reset Layout', 'catch-evolution-pro' ),
			'description'	=> __( 'Please refresh the customizer after saving if reset option is used', 'catch-evolution-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchevolution_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'layout_options',
			'default' 		=> $defaults['reset_sidebar_layout']
		),

		//Homepage/Frontpage Settings
		'front_page_category' => array(
			'id' 			=> 'front_page_category',
			'title' 		=> __( 'Front page posts categories:', 'catch-evolution-pro' ),
			'description'	=> __( 'Only posts that belong to the categories selected here will be displayed on the front page', 'catch-evolution-pro' ),
			'field_type' 	=> 'category-multiple',
			'sanitize' 		=> 'catchevolution_sanitize_category_list',
			'panel' 		=> 'theme_options',
			'section' 		=> 'homepage_settings',
			'default' 		=> $defaults['front_page_category']
		),

		//Excerpt More Settings
		'more_tag_text' => array(
			'id' 			=> 'more_tag_text',
			'title' 		=> __( 'More Tag Text', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'text',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'excerpt_more_tag_settings',
			'default' 		=> $defaults['more_tag_text']
		),
		'excerpt_length' => array(
			'id' 			=> 'excerpt_length',
			'title' 		=> __( 'Excerpt length(words)', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'number',
			'sanitize' 		=> 'catchevolution_sanitize_number_range',
			'panel' 		=> 'theme_options',
			'section' 		=> 'excerpt_more_tag_settings',
			'default' 		=> $defaults['excerpt_length'],
			'input_attrs' 	=> array(
					            'style' => 'width: 45px;',
					            'min'   => 0,
					            'max'   => 999999,
					            'step'  => 1,
					        	)
		),
		'reset_more_tag' => array(
			'id' 			=> 'reset_more_tag',
			'title' 		=> __( 'Check to Reset Excerpt', 'catch-evolution-pro' ),
			'description'	=> __( 'Please refresh the customizer after saving if reset option is used', 'catch-evolution-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchevolution_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'excerpt_more_tag_settings',
			'default' 		=> $defaults['reset_more_tag']
		),

		//Feed URL
		'feed_url' => array(
			'id' 				=> 'feed_url',
			'title' 			=> __( 'Feed Redirect url', 'catch-evolution-pro' ),
			'description'		=> __( ' Add in the Feedburner URL', 'catch-evolution-pro' ),
			'field_type' 		=> 'url',
			'sanitize' 			=> 'esc_url_raw',
			'panel' 			=> 'social_links',
			'section' 			=> 'feed_url',
			'default' 			=> $defaults['feed_url'],
			//'active_callback'	=> 'catchevolution_is_feed_url_present',
		),

		//Footer Editor Option
		'footer_code' => array(
			'id' 				=> 'footer_code',
			'title' 			=> __( 'Footer Editor', 'catch-evolution-pro' ),
			'description'		=> __( 'You can add custom HTML and/or shortcodes, which will be automatically inserted into your theme.
Some shorcodes: [footer-image], [the-year], [site-link], [wp-link] for current year, your site link, wordpress site link respectively.', 'catch-evolution-pro' ),
			'field_type' 		=> 'textarea',
			'sanitize' 			=> 'catchevolution_sanitize_footer_code',
			'panel' 			=> 'theme_options',
			'section' 			=> 'footer_options',
			'default' 			=> $defaults['footer_code'],
		),
		'reset_footer' => array(
			'id' 				=> 'reset_footer',
			'title' 			=> __( 'Check to Reset Footer', 'catch-evolution-pro' ),
			'description'		=> __( 'Please refresh the customizer after saving if reset option is used', 'catch-evolution-pro' ),
			'transport'			=> 'postMessage',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'catchevolution_sanitize_checkbox',
			'panel' 			=> 'theme_options',
			'section' 			=> 'footer_options',
			'default' 			=> $defaults['reset_footer'],
		),

		//Custom Css
		'custom_css' => array(
			'id' 			=> 'custom_css',
			'title' 		=> __( 'Enter your custom CSS styles', 'catch-evolution-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'textarea',
			'sanitize' 		=> 'catchevolution_sanitize_custom_css',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_css',
			'default' 		=> $defaults['custom_css']
		),

		//Update Notifier
		'disable_notifier' => array(
			'id' 			=> 'disable_notifier',
			'title' 		=> __( 'Check to Disable Update Notifier', 'catch-evolution-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchevolution_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'update_notifier',
			'default' 		=> $defaults['disable_notifier']
		),

		//Slider Options
		'enable_slider' => array(
			'id' 			=> 'enable_slider',
			'title' 		=> __( 'Enable Slider', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchevolution_sanitize_select',
			'panel' 		=> 'featured_slider',
			'section' 		=> 'slider_options',
			'default' 		=> $defaults['enable_slider'],
			'choices'		=> catchevolution_enable_slider_options(),
		),
		'select_slider_layout' => array(
			'id' 				=> 'select_slider_layout',
			'title' 			=> __( 'Slider Layout', 'catch-evolution-pro' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'catchevolution_sanitize_select',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['select_slider_layout'],
			'choices'			=> catchevolution_slider_layout(),
			'active_callback'	=> 'catchevolution_is_slider_active',
		),
		'slider_qty' => array(
			'id' 				=> 'slider_qty',
			'title' 			=> __( 'Number of Slides', 'catch-evolution-pro' ),
			'description'		=> __( 'Customizer page needs to be refreshed after saving if number of slides is changed', 'catch-evolution-pro' ),
			'field_type' 		=> 'number',
			'sanitize' 			=> 'catchevolution_sanitize_number_range',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['slider_qty'],
			'input_attrs' 		=> array(
						            'style' => 'width: 45px;',
						            'min'   => 0,
						            'max'   => 20,
						            'step'  => 1,
						        	),
			'active_callback'	=> 'catchevolution_is_slider_active'
		),
		'transition_effect' => array(
			'id' 				=> 'transition_effect',
			'title' 			=> __( 'Transition Effect', 'catch-evolution-pro' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'catchevolution_sanitize_select',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['transition_effect'],
			'choices'			=> catchevolution_transition_effects(),
			'active_callback'	=> 'catchevolution_is_slider_active'
		),
		'transition_delay' => array(
			'id' 				=> 'transition_delay',
			'title' 			=> __( 'Transition Delay', 'catch-evolution-pro' ),
			'description'		=> '',
			'field_type' 		=> 'number',
			'sanitize' 			=> 'catchevolution_sanitize_number_range',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['transition_delay'],
			'input_attrs' 		=> array(
						            'style' => 'width: 45px;',
						            'min'   => 0,
						            'max'   => 999999999,
						            'step'  => 1,
						        	),
			'active_callback'	=> 'catchevolution_is_slider_active'
		),
		'transition_duration' => array(
			'id' 				=> 'transition_duration',
			'title' 			=> __( 'Transition Length', 'catch-evolution-pro' ),
			'description'		=> '',
			'field_type' 		=> 'number',
			'sanitize' 			=> 'catchevolution_sanitize_number_range',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['transition_duration'],
			'input_attrs' 		=> array(
						            'style' => 'width: 45px;',
						            'min'   => 0,
						            'max'   => 999999999,
						            'step'  => 1,
						        	),
			'active_callback'	=> 'catchevolution_is_slider_active'
		),
		'select_slider_type' => array(
			'id' 				=> 'select_slider_type',
			'title' 			=> __( 'Select Slider Type', 'catch-evolution-pro' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'catchevolution_sanitize_select',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['select_slider_type'],
			'choices'			=> catchevolution_slider_types(),
			'active_callback'	=> 'catchevolution_is_slider_active',
		),

		//Featured Post Slider
		'exclude_slider_post' => array(
			'id' 				=> 'exclude_slider_post',
			'title' 			=> __( 'Check to Exclude Slider posts from Homepage posts', 'catch-evolution-pro' ),
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'catchevolution_sanitize_checkbox',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['exclude_slider_post'],
			'active_callback'	=> 'catchevolution_is_post_slider_active'
		),

		//Featured Category Slider
		'slider_category' => array(
			'id' 				=> 'slider_category',
			'title' 			=> __( 'Select Slider Categories', 'catch-evolution-pro' ),
			'description'		=> __( 'Only posts that belong to the categories selected here will be displayed on the front page', 'catch-evolution-pro' ),
			'field_type' 		=> 'category-multiple',
			'sanitize' 			=> 'catchevolution_sanitize_category_list',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['slider_category'],
			'active_callback'	=> 'catchevolution_is_category_slider_active'
		),

		//Social Links
		'disable_footer_social' => array(
			'id' 				=> 'disable_footer_social',
			'title' 			=> __( 'Check to Enable Social Icons in Footer', 'catch-evolution-pro' ),
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'catchevolution_sanitize_checkbox',
			'panel' 			=> 'social_links',
			'section' 			=> 'social_links',
			'default' 			=> $defaults['disable_footer_social'],
		),
		'social_facebook' => array(
			'id' 			=> 'social_facebook',
			'title' 		=> __( 'Facebook', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_facebook']
		),
		'social_twitter' => array(
			'id' 			=> 'social_twitter',
			'title' 		=> __( 'Twitter', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_twitter']
		),
		'social_googleplus' => array(
			'id' 			=> 'social_googleplus',
			'title' 		=> __( 'Google+', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_googleplus']
		),
		'social_pinterest' => array(
			'id' 			=> 'social_pinterest',
			'title' 		=> __( 'Pinterest', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_pinterest']
		),
		'social_youtube' => array(
			'id' 			=> 'social_youtube',
			'title' 		=> __( 'Youtube', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_youtube']
		),
		'social_vimeo' => array(
			'id' 			=> 'social_vimeo',
			'title' 		=> __( 'Vimeo', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_vimeo']
		),
		'social_linkedin' => array(
			'id' 			=> 'social_linkedin',
			'title' 		=> __( 'LinkedIn', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_linkedin']
		),
		'social_aim' => array(
			'id' 			=> 'social_aim',
			'title' 		=> __( 'AIM', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_aim']
		),
		'social_myspace' => array(
			'id' 			=> 'social_myspace',
			'title' 		=> __( 'MySpace', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_myspace']
		),
		'social_flickr' => array(
			'id' 			=> 'social_flickr',
			'title' 		=> __( 'Flickr', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_flickr']
		),
		'social_tumblr' => array(
			'id' 			=> 'social_tumblr',
			'title' 		=> __( 'Tumblr', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_tumblr']
		),
		'social_deviantart' => array(
			'id' 			=> 'social_deviantart',
			'title' 		=> __( 'deviantART', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_deviantart']
		),
		'social_dribbble' => array(
			'id' 			=> 'social_dribbble',
			'title' 		=> __( 'Dribbble', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_dribbble']
		),
		'social_wordpress' => array(
			'id' 			=> 'social_wordpress',
			'title' 		=> __( 'WordPress', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_wordpress']
		),
		'social_rss' => array(
			'id' 			=> 'social_rss',
			'title' 		=> __( 'RSS', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_rss']
		),
		'social_slideshare' => array(
			'id' 			=> 'social_slideshare',
			'title' 		=> __( 'Slideshare', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_slideshare']
		),
		'social_instagram' => array(
			'id' 			=> 'social_instagram',
			'title' 		=> __( 'Instagram', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_instagram']
		),
		'social_skype' => array(
			'id' 			=> 'social_skype',
			'title' 		=> __( 'Skype', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_skype']
		),
		'social_soundcloud' => array(
			'id' 			=> 'social_soundcloud',
			'title' 		=> __( 'Soundcloud', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_soundcloud']
		),
		'social_email' => array(
			'id' 			=> 'social_email',
			'title' 		=> __( 'Email', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'sanitize_email',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_email']
		),
		'social_contact' => array(
			'id' 			=> 'social_contact',
			'title' 		=> __( 'Contact', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_contact']
		),
		'social_xing' => array(
			'id' 			=> 'social_xing',
			'title' 		=> __( 'Xing', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_xing']
		),
		'social_meetup' => array(
			'id' 			=> 'social_meetup',
			'title' 		=> __( 'Meetup', 'catch-evolution-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_meetup']
		),

		//Webmaster Setting
		'google_verification' => array(
			'id' 			=> 'google_verification',
			'title' 		=> __( 'Google Site Verification ID', 'catch-evolution-pro' ),
			'description'	=> __( 'Enter your Google ID number only', 'catch-evolution-pro' ),
			'field_type' 	=> 'text',
			'sanitize' 		=> 'wp_filter_post_kses',
			'panel' 		=> 'webmaster_tool',
			'section' 		=> 'site_verification',
			'default' 		=> $defaults['google_verification']
		),
		'yahoo_verification' => array(
			'id' 			=> 'yahoo_verification',
			'title' 		=> __( 'Yahoo Site Verification ID', 'catch-evolution-pro' ),
			'description'	=> __( 'Enter your Yahoo ID number only', 'catch-evolution-pro' ),
			'field_type' 	=> 'text',
			'sanitize' 		=> 'wp_filter_post_kses',
			'panel' 		=> 'webmaster_tool',
			'section' 		=> 'site_verification',
			'default' 		=> $defaults['yahoo_verification']
		),
		'bing_verification' => array(
			'id' 			=> 'bing_verification',
			'title' 		=> __( 'Bing Site Verification ID', 'catch-evolution-pro' ),
			'description'	=> __( 'Enter your Bing ID number only', 'catch-evolution-pro' ),
			'field_type' 	=> 'text',
			'sanitize' 		=> 'wp_filter_post_kses',
			'panel' 		=> 'webmaster_tool',
			'section' 		=> 'site_verification',
			'default' 		=> $defaults['bing_verification']
		),
		'analytic_header' => array(
			'id' 				=> 'analytic_header',
			'title' 			=> __( 'Code to display on Header', 'catch-evolution-pro' ),
			'description' 		=> __( 'Here you can put scripts from Google, Facebook etc. which will load on Header', 'catch-evolution-pro' ),
			'field_type' 		=> 'textarea',
			'sanitize' 			=> 'wp_kses_stripslashes',
			'panel' 			=> 'webmaster_tool',
			'section' 			=> 'header_footer_codes',
			'default' 			=> $defaults['analytic_header']
		),
		'analytic_footer' => array(
			'id' 				=> 'analytic_footer',
			'title' 			=> __( 'Code to display on Footer', 'catch-evolution-pro' ),
			'description' 		=> __( 'Here you can put scripts from Google, Facebook etc. which will load on Footer', 'catch-evolution-pro' ),
			'field_type' 		=> 'textarea',
			'sanitize' 			=> 'wp_kses_stripslashes',
			'panel' 			=> 'webmaster_tool',
			'section' 			=> 'header_footer_codes',
			'default' 			=> $defaults['analytic_footer']
		),
	);

	//@remove Remove if block when WordPress 4.8 is released
	if( !function_exists( 'has_site_icon' ) ) {
		$settings_favicon = array(
			//Favicon
			'remove_favicon' => array(
				'id' 				=> 'remove_favicon',
				'title' 			=> __( 'Check to Disable Favicon', 'catch-evolution-pro' ),
				'description'		=> '',
				'field_type' 		=> 'checkbox',
				'sanitize' 			=> 'catchevolution_sanitize_checkbox',
				'panel' 			=> 'theme_options',
				'section' 			=> 'favicon',
				'default' 			=> $defaults['remove_favicon'],
			),
			'fav_icon' => array(
				'id' 				=> 'fav_icon',
				'title' 			=> __( 'Fav Icon', 'catch-evolution-pro' ),
				'description'		=> '',
				'field_type' 		=> 'image',
				'sanitize' 			=> 'catchevolution_sanitize_image',
				'panel' 			=> 'theme_options',
				'section' 			=> 'favicon',
				'default' 			=> $defaults['fav_icon'],
			),

			//Web Clip Icon
			'remove_web_clip' => array(
				'id' 				=> 'remove_web_clip',
				'title' 			=> __( 'Check to Disable Web Clip Icon', 'catch-evolution-pro' ),
				'description'		=> '',
				'field_type' 		=> 'checkbox',
				'sanitize' 			=> 'catchevolution_sanitize_checkbox',
				'panel' 			=> 'theme_options',
				'section' 			=> 'web_clip_icon_options',
				'default' 			=> $defaults['remove_web_clip'],
			),
			'web_clip' => array(
				'id' 				=> 'web_clip',
				'title' 			=> __( 'Web Clip Icon', 'catch-evolution-pro' ),
				'description'		=> '',
				'field_type' 		=> 'image',
				'sanitize' 			=> 'catchevolution_sanitize_image',
				'panel' 			=> 'theme_options',
				'section' 			=> 'web_clip_icon_options',
				'default' 			=> $defaults['web_clip'],
			),
		);

		$settings_parameters = array_merge( $settings_parameters, $settings_favicon);
	}

	//@remove Remove if block when WordPress 4.8 is released
	if( !function_exists( 'has_custom_logo' ) ) {
		$settings_logo = array(
			'remove_header_logo' => array(
				'id' 			=> 'remove_header_logo',
				'title' 		=> __( 'Check to Disable Header Logo', 'catch-evolution-pro' ),
				'description'	=> '',
				'field_type' 	=> 'checkbox',
				'sanitize' 		=> 'catchevolution_sanitize_checkbox',
				'panel' 		=> 'theme_options',
				'section' 		=> 'header_options',
				'default' 		=> $defaults['remove_header_logo']
			),
			'featured_logo_header' => array(
				'id' 			=> 'featured_logo_header',
				'title' 		=> __( 'Logo', 'catch-evolution-pro' ),
				'description'	=> '',
				'field_type' 	=> 'image',
				'sanitize' 		=> 'catchevolution_sanitize_image',
				'panel' 		=> 'theme_options',
				'section' 		=> 'header_options',
				'default' 		=> $defaults['featured_logo_header']
			),
		);

		$settings_parameters = array_merge( $settings_parameters, $settings_logo);
	}

	foreach ( $settings_parameters as $option ) {
		$priority = isset($option['priority']) ? $option['priority'] : '';
		$transport = isset($option['transport']) ? $option['transport'] : 'refresh';
		if( 'color' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,$theme_slug . 'options[' . $option['id'] . ']',
					array(
						'label'			=> $option['title'],
						'section'   	=> $theme_slug . $option['section'],
						'settings'  	=> $theme_slug . 'options[' . $option['id'] . ']',
						'priority'		=> $priority,
						'description' 	=> $option['description'],
						'priority'		=> $priority,
					)
				)
			);
		}
		if( 'image' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport,
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Image_Control(
					$wp_customize,$theme_slug . 'options[' . $option['id'] . ']',
					array(
						'label'		=> $option['title'],
						'section'   => $theme_slug . $option['section'],
						'settings'  => $theme_slug . 'options[' . $option['id'] . ']',
						'priority'	=> $priority
					)
				)
			);
		}
		else if ('checkbox' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport,
					)
			);

			$params = array(
						'label'		=> $option['title'],
						'settings'  => $theme_slug . 'options[' . $option['id'] . ']',
						'name'  	=> $theme_slug . 'options[' . $option['id'] . ']',
						'priority'	=> $priority,
					);

			if ( isset( $option['active_callback']  ) ){
				$params['active_callback'] = $option['active_callback'];
			}

			if ( 'header_image' == $option['section'] || 'colors' == $option['section'] ){
				$params['section'] = $option['section'];
			}
			else {
				$params['section']	= $theme_slug . $option['section'];
			}

			$wp_customize->add_control(
				new Catchevolution_Customize_Checkbox(
					$wp_customize,$theme_slug . 'options[' . $option['id'] . ']',
					$params
				)
			);
		}
		else if ('category-multiple' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport,
				)
			);

			$params = array(
						'label'			=> $option['title'],
						'section'		=> $theme_slug . $option['section'],
						'settings'		=> $theme_slug . 'options[' . $option['id'] . ']',
						'description'	=> $option['description'],
						'name'	 		=> $theme_slug . 'options[' . $option['id'] . ']',
						'priority'		=> $priority,
					);

			if ( isset( $option['active_callback']  ) ){
				$params['active_callback'] = $option['active_callback'];
			}

			$wp_customize->add_control(
				new Catchevolution_Customize_Dropdown_Categories_Control (
					$wp_customize,
					$theme_slug . 'options[' . $option['id'] . ']',
					$params
				)
			);
		}
		//For Font Size
		else if( 'multiple-input' == $option['field_type'] ){
			/* Body Font Size */
			$option1_id = $option['id'];
			$option2_id = $option['id'].'_unit';

			$wp_customize->add_setting( $theme_slug .'options['. $option1_id .']', array(
		            'default'        	=> $defaults[$option1_id],
		            'capability'     	=> 'edit_theme_options',
		            'sanitize_callback'	=> $option['sanitize'],
		            'type'				=> 'option',
		        ) );

			$wp_customize->add_setting( $theme_slug .'options['. $option2_id .']', array(
		            'default'        	=> $defaults[$option2_id],
		            'capability'     	=> 'edit_theme_options',
		            'sanitize_callback'	=> $option['sanitize'],
		            'type'				=> 'option',
		        ) );

			$control = new Catchevolution_Customize_Multiple_Input_Control(
	            $wp_customize, $theme_slug .'options['. $option1_id .']', array(
	            'label'    		=> $option['title'],
	            'section'  		=> $theme_slug . $option['section'],
	            'settings'   	=> array (
	                $theme_slug .'options['. $option1_id .']',
	                $theme_slug .'options['. $option2_id .']',
	            )
	        ) );

		    $wp_customize->add_control( $control );
		}
		else {
			//Normal Loop
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'default'			=> $option['default'],
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'transport'			=> $transport,
				)
			);

			// Add setting control
			$params = array(
					'label'			=> $option['title'],
					'settings'		=> $theme_slug . 'options[' . $option['id'] . ']',
					'type'			=> $option['field_type'],
					'description'   => $option['description'],
					'priority'		=> $priority,
				) ;

			if ( isset( $option['choices']  ) ){
				$params['choices'] = $option['choices'];
			}

			if ( isset( $option['active_callback']  ) ){
				$params['active_callback'] = $option['active_callback'];
			}

			if ( isset( $option['input_attrs']  ) ){
				$params['input_attrs'] = $option['input_attrs'];
			}

			if ( 'colors' == $option['section'] || 'header_image' == $option['section'] ){
				$params['section'] = $option['section'];
			}
			else {
				$params['section']	= $theme_slug . $option['section'];
			}

			$wp_customize->add_control(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				$params
			);
		}
	}

	//Add featured post elements with respect to no of featured sliders
	for ( $i = 1; $i <= $options[ 'slider_qty' ]; $i++ ) {
		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_slider][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'catchevolution_sanitize_post_id'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_slider][' . $i . ']',
			array(
				'label'		=> sprintf( __( 'Featured Post Slider #%s', 'catch-evolution-pro' ), $i ),
				'section'   => $theme_slug .'slider_options',
				'settings'  => $theme_slug . 'options[featured_slider][' . $i . ']',
				'type'		=> 'text',
					'input_attrs' => array(
	        		'style' => 'width: 100px;'
	    		),
				'active_callback' 	=> 'catchevolution_is_post_slider_active'
			)
		);
	}

	//Add featured page elements with respect to no of featured slider
	for ( $i = 1; $i <= $options[ 'slider_qty' ]; $i++ ) {
		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_slider_page][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'catchevolution_sanitize_post_id'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_slider_page][' . $i . ']',
			array(
				'label'		=> sprintf( __( 'Featured Page Slider #%s', 'catch-evolution-pro' ), $i ),
				'section'   => $theme_slug .'slider_options',
				'settings'  => $theme_slug . 'options[featured_slider_page][' . $i . ']',
				'type'	   	=> 'dropdown-pages',
				'active_callback' 	=> 'catchevolution_is_page_slider_active'
			)
		);
	}

	//Add featured image elements with respect to no of featured slider
	for ( $i = 1; $i <= $options[ 'slider_qty' ]; $i++ ) {
		$wp_customize->add_setting( $theme_slug . 'options[featured_slider_note]['. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Catchevolution_Note_Control(
			$wp_customize,
			$theme_slug . 'options[featured_slider_note]['. $i .']', array(
	        'active_callback'	=> 'catchevolution_is_image_slider_active',
	        'label'		=> __( 'Featured Slide #', 'catch-evolution-pro' ) . $i,
	        'section'  	=> $theme_slug .'slider_options',
	        'settings'	=> $theme_slug . 'options[featured_slider_note][' . $i . ']',
	        'type'     	=> 'description',
   		) ) );

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_image][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'catchevolution_sanitize_image'
			)
		);

		$wp_customize->add_control( new WP_Customize_Image_Control(
				$wp_customize,
				$theme_slug . 'options[featured_image_slider_image][' . $i . ']',
				array(
					'label'				=> __( 'Image', 'catch-evolution-pro' ),
					'section'   		=> $theme_slug .'slider_options',
					'settings'  		=> $theme_slug . 'options[featured_image_slider_image][' . $i . ']',
					'active_callback' 	=> 'catchevolution_is_image_slider_active'
				)
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_link][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'esc_url_raw'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_link][' . $i . ']',
			array(
				'label'				=> __( 'Link', 'catch-evolution-pro' ),
				'section'   		=> $theme_slug .'slider_options',
				'settings'  		=> $theme_slug . 'options[featured_image_slider_link][' . $i . ']',
				'type'	   			=> 'url',
				'active_callback' 	=> 'catchevolution_is_image_slider_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_base][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'catchevolution_sanitize_checkbox'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_base][' . $i . ']',
			array(
				'label'				=> __( 'Check to Open Link in New Window/Tab ', 'catch-evolution-pro' ),
				'section'   		=> $theme_slug .'slider_options',
				'settings'  		=> $theme_slug . 'options[featured_image_slider_base][' . $i . ']',
				'type'	   			=> 'checkbox',
				'active_callback' 	=> 'catchevolution_is_image_slider_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_title][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'sanitize_text_field'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_title][' . $i . ']',
			array(
				'label'				=> __( 'Title', 'catch-evolution-pro' ),
				'section'   		=> $theme_slug .'slider_options',
				'settings'  		=> $theme_slug . 'options[featured_image_slider_title][' . $i . ']',
				'type'	   			=> 'text',
				'active_callback' 	=> 'catchevolution_is_image_slider_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_content][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'sanitize_text_field'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_content][' . $i . ']',
			array(
				'label'				=> __( 'Content', 'catch-evolution-pro' ),
				'section'   		=> $theme_slug .'slider_options',
				'settings'  		=> $theme_slug . 'options[featured_image_slider_content][' . $i . ']',
				'type'	   			=> 'textarea',
				'active_callback' 	=> 'catchevolution_is_image_slider_active'
			)
		);
	}

	// Reset all settings to default
	$wp_customize->add_section( 'catchevolution_reset_all_settings', array(
		'description'	=> __( 'Caution: Reset all settings to default. Refresh the page after save to view full effects.', 'catch-evolution-pro' ),
		'priority' 		=> 700,
		'title'    		=> __( 'Reset all settings', 'catch-evolution-pro' ),
	) );

	$wp_customize->add_setting( 'catchevolution_options[reset_all_settings]', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback' => 'catchevolution_sanitize_checkbox',
		'type'				=> 'option',
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'catchevolution_options[reset_all_settings]', array(
		'label'    => __( 'Check to reset all settings to default', 'catch-evolution-pro' ),
		'section'  => 'catchevolution_reset_all_settings',
		'settings' => 'catchevolution_options[reset_all_settings]',
		'type'     => 'checkbox'
	) );
	// Reset all settings to default end

	//Important Links
	$wp_customize->add_section( 'important_links', array(
		'priority' 		=> 999,
		'title'   	 	=> __( 'Important Links', 'catch-evolution-pro' ),
	) );

	/**
	 * Has dummy Sanitizaition function as it contains no value to be sanitized
	 */
	$wp_customize->add_setting( 'important_links', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Catchevolution_Important_Links( $wp_customize, 'important_links', array(
        'label'   	=> __( 'Important Links', 'catch-evolution-pro' ),
        'section'  	=> 'important_links',
        'settings' 	=> 'important_links',
        'type'     	=> 'important_links',
    ) ) );
    //Important Links End
}
add_action( 'customize_register', 'catchevolution_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously for catch evolution.
 * And flushes out all transient data on preview
 *
 * @since Catch Evolution 1.6.3
 */
function catchevolution_customize_preview() {
	//Remove transients on preview
	catchevolution_themeoption_invalidate_caches();

	global $catchevolution_options_defaults ,$catchevolution_options_settings;

	$catchevolution_options_settings = catchevolution_options_set_defaults( $catchevolution_options_defaults );
}
add_action( 'customize_preview_init', 'catchevolution_customize_preview' );
add_action( 'customize_save', 'catchevolution_customize_preview' );


/**
 * Custom scripts and styles on Customizer for Catch Evolution
 *
 * @since Catch Evolution 2.3
 */
function catchevolution_customize_scripts() {
	wp_enqueue_script( 'catchevolution_customizer_custom', get_template_directory_uri() . '/inc/panel/customizer-custom-scripts.js', array( 'jquery' ), '20140108', true );

	$catchevolution_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'catch-evolution-pro' ),
		'reset_options' => array(
			'catchevolution_options[reset_header_space]',
			'catchevolution_options[reset_header_image]',
			'catchevolution_options[reset_color]',
			'catchevolution_options[reset_typography]',
			'catchevolution_options[reset_font_size]',
			'catchevolution_options[reset_sidebar_layout]',
			'catchevolution_options[reset_more_tag]',
			'catchevolution_options[reset_footer]',
			'catchevolution_options[reset_all_settings]',
		)
	);

	// Send reset message as object to custom customizer js
	wp_localize_script( 'catchevolution_customizer_custom', 'catchevolution_data', $catchevolution_data );
}
add_action( 'customize_controls_enqueue_scripts', 'catchevolution_customize_scripts' );

//Active callbacks for customizer
require get_template_directory() . '/inc/panel/customizer/customizer-active-callbacks.php';

//Sanitize functions for customizer
require get_template_directory() . '/inc/panel/customizer/customizer-sanitize-functions.php';